@@ -6,11 +6,11 @@ models = {
     }
 
 for m in models.keys():
-    makeYAML(mechInput=models[m],
-             outputPath='test/outputs/Dec27')
+    # makeYAML(mechInput=models[m],
+    #          outputPath='test/outputs/Dec27')
     makeYAML(mechInput=models[m],
              outputPath='test/outputs/Dec27',
              allPdep=True)
-    makeYAML(mechInput=models[m],
-             outputPath='test/outputs/Dec27',
-             allPLOG=True)
\ No newline at end of file
+    # makeYAML(mechInput=models[m],
+    #          outputPath='test/outputs/Dec27',
+    #          allPLOG=True)
\ No newline at end of file
